X-Git-Url: https://git.p6c8.net/jirafeau_mojo42.git/blobdiff_plain/486d4f5ea5be5649cdbc478a9a9948af37e73366..bfbbf72959faa385b97d250484be1d25e4fd22aa:/index.php?ds=sidebyside
diff --git a/index.php b/index.php
index 6c0a03a..f7aeb04 100644
--- a/index.php
+++ b/index.php
@@ -2,7 +2,7 @@
/*
* Jirafeau, your web file repository
* Copyright (C) 2013
- * Jerome Jutteau
+ * Jerome Jutteau
* Jimmy Beauvois
*
* This program is free software: you can redistribute it and/or modify
@@ -27,43 +27,41 @@ require(JIRAFEAU_ROOT . 'lib/lang.php');
check_errors($cfg);
if (has_error()) {
+ require(JIRAFEAU_ROOT . 'lib/template/header.php');
show_errors();
require(JIRAFEAU_ROOT . 'lib/template/footer.php');
exit;
}
-
require(JIRAFEAU_ROOT . 'lib/template/header.php');
+// Logout action
+if (isset($_POST['action']) && (strcmp($_POST['action'], 'logout') == 0)) {
+ jirafeau_session_end();
+}
+
/* Check if user is allowed to upload. */
-// First check: Challenge by IP NO PASSWORD
-if (true === jirafeau_challenge_upload_ip($cfg['upload_ip_nopassword'], get_ip_address($cfg))) {
- $_SESSION['upload_auth'] = true;
- $_POST['upload_password'] = '';
- $_SESSION['user_upload_password'] = $_POST['upload_password'];
+// First check: Is user already logged
+if (jirafeau_user_session_logged()) {}
+// Second check: Challenge by IP NO PASSWORD
+elseif (true === jirafeau_challenge_upload_ip_without_password($cfg, get_ip_address($cfg))) {
+ jirafeau_user_session_start();
}
-// Second check: Challenge by IP
-elseif (true === jirafeau_challenge_upload_ip($cfg['upload_ip'], get_ip_address($cfg))) {
+// Third check: Challenge by IP
+elseif (true === jirafeau_challenge_upload_ip($cfg, get_ip_address($cfg))) {
// Is an upload password required?
if (jirafeau_has_upload_password($cfg)) {
- // Logout action
- if (isset($_POST['action']) && (strcmp($_POST['action'], 'logout') == 0)) {
- session_unset();
- }
-
// Challenge by password
- // â¦save successful logins in session
if (isset($_POST['upload_password'])) {
if (jirafeau_challenge_upload_password($cfg, $_POST['upload_password'])) {
- $_SESSION['upload_auth'] = true;
- $_SESSION['user_upload_password'] = $_POST['upload_password'];
+ jirafeau_user_session_start();
} else {
- $_SESSION['admin_auth'] = false;
+ jirafeau_session_end();
jirafeau_fatal_error(t('BAD_PSW'), $cfg);
}
}
// Show login form if user session is not authorized yet
- if (true === empty($_SESSION['upload_auth'])) {
+ if (!jirafeau_user_session_logged()) {
?>
-
+
@@ -118,7 +114,7 @@ else {
-
+
-
+
@@ -138,7 +134,7 @@ else {
-
+
@@ -166,19 +162,27 @@ else {
- ')"/>
+ 0) {
+ echo t('2_BIG') . ', ' . t('FILE_LIM') . " " . $cfg['maximal_upload_size'] . " MB.";
+ }
+ ?>')"/>
-
- : |
- |
-
+ ' . t('ONE_TIME_DL') . ': | ';
+ echo ' | ';
+ }
+ ?>
|
- |
+ |
|
@@ -201,6 +205,10 @@ else {
'value' => 'week',
'label' => '1_W'
),
+ array(
+ 'value' => 'fortnight',
+ 'label' => '2_W'
+ ),
array(
'value' => 'month',
'label' => '1_M'
@@ -230,47 +238,37 @@ else {
0) {
+ if ($cfg['maximal_upload_size'] >= 1024) {
echo '' . t('FILE_LIM');
- echo " " . $cfg['maximal_upload_size'] . " MB
";
+ echo " " . number_format($cfg['maximal_upload_size'] / 1024, 2) . " GB.";
+ } elseif ($cfg['maximal_upload_size'] > 0) {
+ echo '' . t('FILE_LIM');
+ echo " " . $cfg['maximal_upload_size'] . " MB.
";
+ } else {
+ echo '';
}
?>
-
-
-
-
-
+ if (jirafeau_user_session_logged()) {
+ ?>
@@ -285,8 +283,11 @@ else {
document.getElementById('send').style.display = 'none';
if (!check_html5_file_api ())
document.getElementById('max_file_size').innerHTML = '';
+ $max_size = jirafeau_get_max_upload_size();
+ if ($max_size > 0) {
+ echo t('NO_BROWSER_SUPPORT') . $max_size;
+ }
+ ?>';
addCopyListener('upload_link_button', 'upload_link');
addCopyListener('preview_link_button', 'preview_link');